from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

_74xgxx = SchLib(tool=SKIDL).add_parts(*[
        Part(name='74AUC1G74',dest=TEMPLATE,tool=SKIDL,keywords='Single D Flip-Flop D CMOS',description='Single D Flip-Flop, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUP1G74'],pins=[
            Pin(num='1',name='C',do_erc=True),
            Pin(num='2',name='D',do_erc=True),
            Pin(num='3',name='~Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='~CLR',do_erc=True),
            Pin(num='7',name='~PRE',do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74CBT1G125',dest=TEMPLATE,tool=SKIDL,keywords='Single FET Bus Switch',description='Single FET Bus Switch',ref_prefix='U',num_units=1,fplist=['SOT*', 'SC*'],do_erc=True,aliases=['74CB3T1G125', '74CBTD1G125', '74CBTLV1G125'],pins=[
            Pin(num='1',name='~OE',do_erc=True),
            Pin(num='2',name='A',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='B',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74CBT1G384',dest=TEMPLATE,tool=SKIDL,keywords='Single FET Bus Switch',description='Single FET Bus Switch',ref_prefix='U',num_units=1,fplist=['SOT*', 'SC*'],do_erc=True,aliases=['74CBTD1G384'],pins=[
            Pin(num='1',name='A',do_erc=True),
            Pin(num='2',name='B',func=Pin.TRISTATE,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~OE',do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G00',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate NAND LVC CMOS',description='Single NAND Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AHC1G00', '74AHCT1G00', '74AUC1G00', '74AUP1G00'],pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G02',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate NOR LVC CMOS',description='Single NOR Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AHC1G02', '74AHCT1G02', '74AUC1G02', '74AUP1G02'],pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G04',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate NOT LVC CMOS',description='74LVC1G04, Single NOT Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74LVC1GU04', '74AHC1G04', '74AHCT1G04', '74AUC1G04', '74AUP1G04', '74AHC1GU04', '74AHCT1GU04', '74AUC1GU04', '74AUP1GU04'],pins=[
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G06',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate NOT LVC CMOS Open Drain',description='Single NOT Gate w/ Open Drain, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AUC1G06', '74AUP1G06'],pins=[
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G07',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate Buff LVC CMOS Open Drain',description='Single Buffer Gate w/ Open Drain, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AUC1G07', '74AUP1G07'],pins=[
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G08',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate AND LVC CMOS',description='Single AND Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AHC1G08', '74AHCT1G08', '74AUC1G08', '74AUP1G08'],pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G0832',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate AND-OR LVC CMOS',description='Single AND-OR Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC1G10',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate NAND 3in LVC CMOS',description='Single NAND 3in Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC1G11',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate AND 3in LVC CMOS',description='Single AND 3in Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC1G123',dest=TEMPLATE,tool=SKIDL,keywords='Single Mono Multivibrator CMOS',description='Single Retrigerrable Monostabile Multivibrator, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='1',name='~A',do_erc=True),
            Pin(num='2',name='B',do_erc=True),
            Pin(num='3',name='~CLR',do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='Cext',do_erc=True),
            Pin(num='7',name='Rext',do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G125',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate Buff Tri-State LVC CMOS',description='Single Buffer Gate Tri-State, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AHC1G125', '74AHCT1G125', '74AUC1G125', '74AUP1G125'],pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G126',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate Buff Tri-State LVC CMOS',description='Single Buffer Gate Tri-State, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AHC1G126', '74AHCT1G126', '74AUC1G126', '74AUP1G126'],pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G139',dest=TEMPLATE,tool=SKIDL,keywords='Single Decoder LVC CMOS',description='2 to 4 Decoder, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='1',name='A',do_erc=True),
            Pin(num='2',name='B',do_erc=True),
            Pin(num='3',name='Y3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Y2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='Y1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='Y0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G14',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate NOT Schmidt LVC CMOS',description='Single Schmidt NOT Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AHC1G14', '74AHCT1G14', '74AUC1G14', '74AUP1G14'],pins=[
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G17',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate Buff Schmidt LVC CMOS',description='Single Schmidt Buffer Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AUC1G17', '74AUP1G17'],pins=[
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G175',dest=TEMPLATE,tool=SKIDL,keywords='Single D Flip-Flop Clear CMOS',description='Single D Flip-Flop w/ Asnynchronus Clear, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SC*'],do_erc=True,pins=[
            Pin(num='1',name='C',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='D',do_erc=True),
            Pin(num='4',name='Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~CLR',do_erc=True)]),
        Part(name='74LVC1G18',dest=TEMPLATE,tool=SKIDL,keywords='Single Demux LVC CMOS',description='Single Demultiplexer, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AUC1G18'],pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~',func=Pin.TRISTATE,do_erc=True)]),
        Part(name='74LVC1G19',dest=TEMPLATE,tool=SKIDL,keywords='Single Decoder LVC CMOS',description='1 of 2 Decoder, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AUC1G19'],pins=[
            Pin(num='1',name='A',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~E',do_erc=True),
            Pin(num='4',name='Y1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='Y0',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='74LVC1G240',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate Buff/Drv Tri-State LVC CMOS',description='Single Buffer/Driver Gate Tri-State, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AUC1G240', '74AUP1G240'],pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G27',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate NOR 3in LVC CMOS',description='Single NOR 3in Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC1G29',dest=TEMPLATE,tool=SKIDL,keywords='Single Decoder LVC CMOS',description='2 of 3 Decoder, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='1',name='~G',do_erc=True),
            Pin(num='2',name='Y1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='A2',do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Y2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='A1',do_erc=True),
            Pin(num='7',name='Y0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G3157',dest=TEMPLATE,tool=SKIDL,keywords='SPDT Analog Switch CMOS',description='SPDT Analog Swich, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SC*'],do_erc=True,pins=[
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='~',do_erc=True),
            Pin(num='1',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='~',func=Pin.BIDIR,do_erc=True)]),
        Part(name='74LVC1G32',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate OR LVC CMOS',description='Single OR Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AHC1G32', '74AHCT1G32', '74AUC1G32', '74AUP1G32'],pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G3208',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate OR-AND LVC CMOS',description='Single OR-AND Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC1G332',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate OR 3in LVC CMOS',description='Single OR 3in Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC1G34',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate Buff LVC CMOS',description='Single Buffef Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AUP1G34'],pins=[
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G373',dest=TEMPLATE,tool=SKIDL,keywords='Single D Latch CMOS',description='Single D Latch, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SC*'],do_erc=True,pins=[
            Pin(num='1',name='LE',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='D',do_erc=True),
            Pin(num='4',name='Q',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~OE',do_erc=True)]),
        Part(name='74LVC1G374',dest=TEMPLATE,tool=SKIDL,keywords='Single D Flip-Flop Tri-State CMOS',description='Single D Flip-Flop Tri-State Output, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SC*'],do_erc=True,pins=[
            Pin(num='1',name='CLK',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='D',do_erc=True),
            Pin(num='4',name='Q',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~OE',do_erc=True)]),
        Part(name='74LVC1G38',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate NAND Open Drain LVC CMOS',description='Single NAND Gate Open Drain, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G386',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate EX-OR 3in LVC CMOS',description='Single EX-OR 3in Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC1G57',dest=TEMPLATE,tool=SKIDL,keywords='Configurable Single Gate LVC CMOS',description='Configurable Multi-Function Single Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SC*'],do_erc=True,aliases=['74AUP1G57', '74LVC1G97', '74AUP1G97'],pins=[
            Pin(num='1',name='IN1',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='IN0',do_erc=True),
            Pin(num='4',name='Y',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='IN2',do_erc=True)]),
        Part(name='74LVC1G58',dest=TEMPLATE,tool=SKIDL,keywords='Configurable Single Gate LVC CMOS',description='Configurable Multi-Function Single Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SC*'],do_erc=True,aliases=['74AUP1G58', '74LVC1G98', '74AUP1G98'],pins=[
            Pin(num='1',name='IN1',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='IN0',do_erc=True),
            Pin(num='4',name='~Y',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='IN2',do_erc=True)]),
        Part(name='74LVC1G66',dest=TEMPLATE,tool=SKIDL,keywords='Single Analog Switch',description='Single Analog Switch',ref_prefix='U',num_units=1,fplist=['SOT*', 'SC*'],do_erc=True,aliases=['74AUC1G66'],pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G79',dest=TEMPLATE,tool=SKIDL,keywords='Single D Flip-Flop D CMOS',description='Single D Flip-Flop, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG*'],do_erc=True,aliases=['74AUC1G79', '74AUP1G79'],pins=[
            Pin(num='1',name='D',do_erc=True),
            Pin(num='2',name='C',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G80',dest=TEMPLATE,tool=SKIDL,keywords='Single D Flip-Flop CMOS',description='Single D Flip-Flop Iverted Output, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG*'],do_erc=True,aliases=['74AUC1G80', '74AUP1G80'],pins=[
            Pin(num='1',name='D',do_erc=True),
            Pin(num='2',name='C',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G86',dest=TEMPLATE,tool=SKIDL,keywords='Single Gate EX-OR LVC CMOS',description='Single EX-OR Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SOT*', 'SG-*'],do_erc=True,aliases=['74AHC1G86', '74AHCT1G86', '74AUC1G86'],pins=[
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC1G99',dest=TEMPLATE,tool=SKIDL,keywords='Configurable Single Gate LVC CMOS',description='Configurable Multi-Function Single Gate, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUP1G99'],pins=[
            Pin(num='1',name='~OE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='A',do_erc=True),
            Pin(num='3',name='B',do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='C',do_erc=True),
            Pin(num='6',name='D',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='Y',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC2G00',dest=TEMPLATE,tool=SKIDL,keywords='Dual Gate NAND LVC CMOS',description='Dual NAND Gate, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUC2G00'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC2G02',dest=TEMPLATE,tool=SKIDL,keywords='Dual Gate NOR LVC CMOS',description='Dual NOR Gate, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUC2G02'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC2G04',dest=TEMPLATE,tool=SKIDL,keywords='Dual Gate NOT LVC CMOS',description='74LVC2G04, Dual NOT Gate, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SG-*', 'SOT*'],do_erc=True,aliases=['74AUC2G04', '74LVC2GU04', '74AUC2GU04'],pins=[
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='74LVC2G06',dest=TEMPLATE,tool=SKIDL,keywords='Dual Gate NOT Open Drain LVC CMOS',description='Dual NOT Gate w/ Open Drain, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SG-*', 'SOT*'],do_erc=True,aliases=['74AUC2G06'],pins=[
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='74LVC2G07',dest=TEMPLATE,tool=SKIDL,keywords='Dual Gate Buffer Open Drain LVC CMOS',description='Dual Buffer w/ Open Drain, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SG-*', 'SOT*'],do_erc=True,aliases=['74AUC2G07'],pins=[
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='74LVC2G08',dest=TEMPLATE,tool=SKIDL,keywords='Dual Gate AND LVC CMOS',description='Dual AND Gate, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUC2G08'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC2G125',dest=TEMPLATE,tool=SKIDL,keywords='Dual Buff Tri-State LVC CMOS',description='Dual Buffer Tri-State, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['VSSOP*'],do_erc=True,aliases=['74AUC2G125'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='3',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='7',name='~',do_erc=True)]),
        Part(name='74LVC2G126',dest=TEMPLATE,tool=SKIDL,keywords='Dual Buff Tri-State LVC CMOS',description='Dual Buffer Tri-State, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['VSSOP*'],do_erc=True,aliases=['74AUC2G126'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='3',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='7',name='~',do_erc=True)]),
        Part(name='74LVC2G14',dest=TEMPLATE,tool=SKIDL,keywords='Dual Gate NOT Schmidt LVC CMOS',description='Dual NOT Gate Schmidt Triggered, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SG-*', 'SOT*'],do_erc=True,pins=[
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='74LVC2G157',dest=TEMPLATE,tool=SKIDL,keywords='Single Mux CMOS',description='Single 2 to 1 Multiplexer, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='1',name='A',do_erc=True),
            Pin(num='2',name='B',do_erc=True),
            Pin(num='3',name='~Y',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Y',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='~A~/B',do_erc=True),
            Pin(num='7',name='~G',do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC2G17',dest=TEMPLATE,tool=SKIDL,keywords='Dual Buffer Schmidt LVC CMOS',description='Dual Buffer Schmidt Triggered, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SG-*', 'SOT*'],do_erc=True,pins=[
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='74LVC2G240',dest=TEMPLATE,tool=SKIDL,keywords='Dual Inv Buff Tri-State LVC CMOS',description='Dual Inverter Buffer Tri-State, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['VSSOP*'],do_erc=True,aliases=['74AUC2G240'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='3',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='7',name='~',do_erc=True)]),
        Part(name='74LVC2G241',dest=TEMPLATE,tool=SKIDL,keywords='Dual Buff Tri-State LVC CMOS',description='Dual Buffer Tri-State, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['VSSOP*'],do_erc=True,aliases=['74AUC2G241'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='3',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='7',name='~',do_erc=True)]),
        Part(name='74LVC2G32',dest=TEMPLATE,tool=SKIDL,keywords='Dual Gate OR LVC CMOS',description='Dual OR Gate, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUC2G32'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC2G34',dest=TEMPLATE,tool=SKIDL,keywords='Dual Buffer LVC CMOS',description='Dual Buffer, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SG-*', 'SOT*'],do_erc=True,aliases=['74AUC2G34'],pins=[
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='74LVC2G38',dest=TEMPLATE,tool=SKIDL,keywords='Dual Gate NAND Open Drain LVC CMOS',description='Dual NAND Gate w/ Open Drain, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='3',name='~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC2G53',dest=TEMPLATE,tool=SKIDL,keywords='Analog Switch 1 to 2 CMOS',description='1 to 2 Analog Swich Mux/Demux, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUC2G53'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='~',func=Pin.BIDIR,do_erc=True)]),
        Part(name='74LVC2G66',dest=TEMPLATE,tool=SKIDL,keywords='Dual Analog Switch',description='Dual Analog Switch',ref_prefix='U',num_units=2,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUC2G66'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',func=Pin.TRISTATE,do_erc=True),
            Pin(num='7',name='~',do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='6',name='~',func=Pin.TRISTATE,do_erc=True)]),
        Part(name='74LVC2G74',dest=TEMPLATE,tool=SKIDL,keywords='Single D Flip-Flop D CMOS',description='74AUC1G74, Single D Flip-Flop, Low-Voltage CMOS',ref_prefix='U',num_units=1,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='1',name='C',do_erc=True),
            Pin(num='2',name='D',do_erc=True),
            Pin(num='3',name='~Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='~CLR',do_erc=True),
            Pin(num='7',name='~PRE',do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='74LVC2G79',dest=TEMPLATE,tool=SKIDL,keywords='Dual D Flip-Flop D CMOS',description='Dual D Flip-Flop, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUC2G79'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='C',do_erc=True),
            Pin(num='2',name='D',do_erc=True),
            Pin(num='7',name='Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='C',do_erc=True),
            Pin(num='6',name='D',do_erc=True)]),
        Part(name='74LVC2G80',dest=TEMPLATE,tool=SKIDL,keywords='Dual D Flip-Flop Negative CMOS',description='Dual D Flip-Flop w/ Negative Output, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUC2G80'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='C',do_erc=True),
            Pin(num='2',name='D',do_erc=True),
            Pin(num='7',name='~Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~Q',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='C',do_erc=True),
            Pin(num='6',name='D',do_erc=True)]),
        Part(name='74LVC2G86',dest=TEMPLATE,tool=SKIDL,keywords='Dual Gate EX-OR LVC CMOS',description='Dual EX-OR Gate, Low-Voltage CMOS',ref_prefix='U',num_units=2,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74AUC2G86'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='2',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='~',do_erc=True),
            Pin(num='6',name='~',do_erc=True)]),
        Part(name='74LVC3G04',dest=TEMPLATE,tool=SKIDL,keywords='Triple Gate NOT LVC CMOS',description='74LVC3G04, Triple NOT Gate, Low-Voltage CMOS',ref_prefix='U',num_units=3,fplist=['SSOP*', 'VSSOP*'],do_erc=True,aliases=['74LVC3GU04'],pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='~',do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='5',name='~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='74LVC3G06',dest=TEMPLATE,tool=SKIDL,keywords='Triple Gate NOT Open Drain LVC CMOS',description='Triple NOT Gate w/ Open Drain, Low-Voltage CMOS',ref_prefix='U',num_units=3,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='2',name='~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='6',name='~',do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='5',name='~',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='74LVC3G07',dest=TEMPLATE,tool=SKIDL,keywords='Triple Buff Open Drain LVC CMOS',description='Triple Buffer w/ Open Drain, Low-Voltage CMOS',ref_prefix='U',num_units=3,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='2',name='~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='6',name='~',do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='5',name='~',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='74LVC3G14',dest=TEMPLATE,tool=SKIDL,keywords='Triple NOT Schmidt LVC CMOS',description='Triple NOT Gate Schmidt, Low-Voltage CMOS',ref_prefix='U',num_units=3,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='~',do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='5',name='~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='74LVC3G17',dest=TEMPLATE,tool=SKIDL,keywords='Triple Buf Schmidt LVC CMOS',description='Triple Buffer Schmidt, Low-Voltage CMOS',ref_prefix='U',num_units=3,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='~',do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='5',name='~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='74LVC3G34',dest=TEMPLATE,tool=SKIDL,keywords='Triple Buf LVC CMOS',description='Triple Buffer, Low-Voltage CMOS',ref_prefix='U',num_units=3,fplist=['SSOP*', 'VSSOP*'],do_erc=True,pins=[
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='~',do_erc=True),
            Pin(num='7',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='~',do_erc=True),
            Pin(num='3',name='~',do_erc=True),
            Pin(num='5',name='~',func=Pin.OUTPUT,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

transf = SchLib(tool=SKIDL).add_parts(*[
        Part(name='TEZ0.5-D-1',dest=TEMPLATE,tool=SKIDL,keywords='0.5VA PCB Transformer Single Secondary',description='TEZ0.5/D/x, 0.5VA, Single Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*22x24*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ0.5-D-2',dest=TEMPLATE,tool=SKIDL,keywords='0.5VA PCB Transformer Dual Secondary',description='TEZ0.5/D/x-x, 0.5VA, Dual Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*22x24*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ1.5-D-1',dest=TEMPLATE,tool=SKIDL,keywords='1.5VA PCB Transformer Single Secondary',description='TEZ1.5/D/x, 1.5VA, Single Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*28x33*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ1.5-D-2',dest=TEMPLATE,tool=SKIDL,keywords='1.5VA PCB Transformer Dual Secondary',description='TEZ1.5/D/x-x, 1.5VA, Dual Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ+28x33*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ10.0-D-1',dest=TEMPLATE,tool=SKIDL,keywords='10VA PCB Transformer Single Secondary',description='TEZ10.0/D/x, 10VA, Single Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*44x52*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ10.0-D-2',dest=TEMPLATE,tool=SKIDL,keywords='10VA PCB Transformer Dual Secondary',description='TEZ10.0/D/x-x, 10VA, Dual Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*44x52*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ16.0-D-1',dest=TEMPLATE,tool=SKIDL,keywords='16VA PCB Transformer Single Secondary',description='TEZ16.0/D/x, 16VA, Single Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*47x57*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ16.0-D-2',dest=TEMPLATE,tool=SKIDL,keywords='16VA PCB Transformer Dual Secondary',description='TEZ16.0/D/x-x, 16VA, Dual Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*47x57*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ2.0-D-1',dest=TEMPLATE,tool=SKIDL,keywords='2VA PCB Transformer Single Secondary',description='TEZ2.0/D/x, 2VA, Single Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*28x33*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ2.0-D-2',dest=TEMPLATE,tool=SKIDL,keywords='2VA PCB Transformer Dual Secondary',description='TEZ2.0/D/x-x, 2VA, Dual Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*28x33*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ2.5-D-1',dest=TEMPLATE,tool=SKIDL,keywords='2.5VA PCB Transformer Single Secondary',description='TEZ2.5/D/x, 2.5VA, Single Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*28x33*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ2.5-D-2',dest=TEMPLATE,tool=SKIDL,keywords='2.5VA PCB Transformer Dual Secondary',description='TEZ2.5/D/x-x, 2.5VA, Dual Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*28x33*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ2.6-D-1',dest=TEMPLATE,tool=SKIDL,keywords='2.6VA PCB Transformer Single Secondary',description='TEZ2.6/D/x, 2.6VA, Single Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*28x33*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ2.6-D-2',dest=TEMPLATE,tool=SKIDL,keywords='2.6VA PCB Transformer Dual Secondary',description='TEZ2.6/D/x-x, 2.6VA, Dual Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*28x33*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ4.0-D-1',dest=TEMPLATE,tool=SKIDL,keywords='4VA PCB Transformer Single Secondary',description='TEZ4.0/D/x, 4VA, Single Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*35x42*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ4.0-D-2',dest=TEMPLATE,tool=SKIDL,keywords='4VA PCB Transformer Dual Secondary',description='TEZ4.0/D/x-x, 4VA, Dual Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*35x42*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ6.0-D-1',dest=TEMPLATE,tool=SKIDL,keywords='6VA PCB Transformer Single Secondary',description='TEZ6.0/D/x, 6VA, Single Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*38x45*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TEZ6.0-D-2',dest=TEMPLATE,tool=SKIDL,keywords='6VA PCB Transformer Dual Secondary',description='TEZ6.0/D/x-x, 6VA, Dual Secondary, Cast Resin Transformer, PCB',ref_prefix='TR',num_units=1,fplist=['Transformer*Breve*TEZ*38x45*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TR1-SO8',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TR60_FC',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TR60_IC',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TR60_IC2',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TRANSF1',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TRANSF2',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TRANSF3',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TRANSF4',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TRANSF5',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TRANSF6',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TRANSF7',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='TRANSF8',dest=TEMPLATE,tool=SKIDL,do_erc=True)])


# -*- coding: utf-8 -*-

# MIT license
#
# Copyright (C) 2018 by XESS Corp.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

"""
Handles parts.
"""

from __future__ import unicode_literals
from __future__ import print_function
from __future__ import division
from __future__ import absolute_import

from builtins import super
from builtins import str
from builtins import int
from builtins import range
from builtins import dict
from builtins import zip
from future import standard_library
standard_library.install_aliases()

try:
    import __builtin__ as builtins
except ImportError:
    import builtins

from copy import copy

try:
    from PySpice.Unit.Unit import UnitValue
except ImportError:
    # PySpice is not supported in Python 2, so need to make a dummy class
    # to replicate a class from PySpice.
    class UnitValue:
        pass

from .defines import *
from .utilities import *


class Part(object):
    """
    A class for storing a definition of a schematic part.

    Attributes:
        ref: String storing the reference of a part within a schematic (e.g., 'R5').
        value: String storing the part value (e.g., '3K3').
        footprint: String storing the PCB footprint associated with a part (e.g., SOIC-8).
        pins: List of Pin objects for this part.

    Args:
        lib: Either a SchLib object or a schematic part library file name.
        name: A string with name of the part to find in the library, or to assign to
            the part defined by the part definition.
        dest: String that indicates where the part is destined for (e.g., LIBRARY).
        tool: The format for the library file or part definition (e.g., KICAD).
        connections: A dictionary with part pin names/numbers as keys and the
            names of nets to which they will be connected as values. For example:
            { 'IN-':'a_in', 'IN+':'GND', '1':'AMPED_OUTPUT', '14':'VCC', '7':'GND' }
        part_defn: A list of strings that define the part (usually read from a
            schematic library file).
        circuit: The Circuit object this Part belongs to.

    Keyword Args:
        attribs: Name/value pairs for setting attributes for the part.
            For example, manf_num='LM4808MP-8' would create an attribute
            named 'manf_num' for the part and assign it the value 'LM4808MP-8'.

    Raises:
        * Exception if the part library and definition are both missing.
        * Exception if an unknown file format is requested.
    """

    def __init__(self,
                 lib=None,
                 name=None,
                 dest=NETLIST,
                 tool=None,
                 connections=None,
                 part_defn=None,
                 circuit=None,
                 **attribs):

        import skidl
        from .SchLib import SchLib
        from .defines import TEMPLATE, NETLIST, LIBRARY, SKIDL

        if tool is None:
            tool = skidl.get_default_tool()

        # Setup some part attributes that might be overwritten later on.
        self.do_erc = True  # Allow part to be included in ERC.
        self.unit = {
        }  # Dictionary for storing subunits of the part, if desired.
        self.pins = []  # Start with no pins, but a place to store them.
        self.name = name  # Assign initial part name. (Must come after circuit is assigned.)
        self.description = ''  # Make sure there is a description, even if empty.
        self._ref = ''  # Provide a member for holding a reference.
        self.ref_prefix = ''  # Provide a member for holding the part reference prefix.
        self.tool = tool  # Initial type of part (SKIDL, KICAD, etc.)
        self.circuit = None  # Part starts off unassociated with any circuit.

        # Create a Part from a library entry.
        if lib:
            # If the lib argument is a string, then create a library using the
            # string as the library file name.
            if isinstance(lib, basestring):
                try:
                    libname = lib
                    lib = SchLib(filename=libname, tool=tool)
                except Exception as e:
                    if skidl.QUERY_BACKUP_LIB:
                        logger.warning(
                            'Could not load KiCad schematic library "{}", falling back to backup library.'
                            .format(libname))
                        lib = skidl.load_backup_lib()
                        if not lib:
                            raise e
                    else:
                        raise e

            # Make a copy of the part from the library but don't add it to the netlist.
            part = lib[name].copy(1, TEMPLATE)

            # Overwrite self with the new part.
            self.__dict__.update(part.__dict__)

            # Make sure all the pins have a valid reference to this part.
            self.associate_pins()

            # Store the library name of this part.
            self.lib = getattr(lib, 'filename', None)

        # Otherwise, create a Part from a part definition. If the part is
        # destined for a library, then just get its name. If it's going into
        # a netlist, then parse the entire part definition.
        elif part_defn:
            self.part_defn = part_defn
            self.parse(just_get_name=(dest != NETLIST))

        # If the part is destined for a SKiDL library, then it will be defined
        # by the additional attribute values that are passed.
        elif tool == SKIDL and name:
            pass

        else:
            logger.error(
                "Can't make a part without a library & part name or a part definition."
            )
            raise Exception

        # If the part is going to be an element in a circuit, then add it to the
        # the circuit and make any indicated pin/net connections.
        if dest != LIBRARY:
            if dest == NETLIST:
                # If no Circuit object is given, then use the default Circuit that always exists.
                # Always set circuit first because naming the part requires a lookup
                # of existing names in the circuit.
                if not circuit:
                    circuit = default_circuit  # pylint: disable=undefined-variable
                circuit += self
            elif dest == TEMPLATE:
                # If this is just a part template, don't add the part to the circuit.
                # Just place the reference to the Circuit object in the template.
                if not circuit:
                    self.circuit = default_circuit  # pylint: disable=undefined-variable
                self.circuit = circuit

            # Add any net/pin connections to this part that were passed as arguments.
            if isinstance(connections, dict):
                for pin, net in connections.items():
                    net += self[pin]

            # Add any other passed-in attributes to the part.
            for k, v in attribs.items():
                setattr(self, k, v)

    def _find_min_max_pins(self):
        """ Return the minimum and maximum pin numbers for the part. """
        pin_nums = []
        try:
            for p in self.pins:
                try:
                    pin_nums.append(int(p.num))
                except ValueError:
                    pass
        except AttributeError:
            # This happens if the part has no pins.
            pass
        try:
            return min(pin_nums), max(pin_nums)
        except ValueError:
            # This happens if the part has no integer-labeled pins.
            return 0, 0

    def parse(self, just_get_name=False):
        """
        Create a part from its stored part definition.

        Args:
            just_get_name: When true, just get the name and aliases for the
                part. Leave the rest unparsed.
        """

        try:
            parse_func = getattr(self, '_parse_lib_part_{}'.format(self.tool))
            parse_func(just_get_name)
        except AttributeError:
            logger.error(
                "Can't create a part with an unknown ECAD tool file format: {}.".
                format(self.tool))
            raise Exception

    def associate_pins(self):
        """
        Make sure all the pins in a part have valid references to the part.
        """
        for p in self.pins:
            p.part = self

    def copy(self, num_copies=1, dest=NETLIST, circuit=None, **attribs):
        """
        Make zero or more copies of this part while maintaining all pin/net
        connections.

        Args:
            num_copies: Number of copies to make of this part.
            dest: Indicates where the copy is destined for (e.g., NETLIST).

        Keyword Args:
            attribs: Name/value pairs for setting attributes for the copy.

        Returns:
            A list of Part copies or a single Part if num_copies==1.

        Raises:
            Exception if the requested number of copies is a non-integer or negative.

        Notes:
            An instance of a part can be copied just by calling it like so::

                res = Part('device','R')    # Get a resistor.
                res_copy = res(value='1K')  # Copy the resistor and set resistance value.

            You can also use the multiplication operator to make copies::

                cap = Part('device', 'C')   # Get a capacitor
                caps = 10 * cap             # Make an array with 10 copies of it.
        """

        from .defines import NETLIST
        from .Circuit import Circuit

        num_copies = max(num_copies, find_num_copies(**attribs))

        # Check that a valid number of copies is requested.
        if not isinstance(num_copies, int):
            logger.error(
                "Can't make a non-integer number ({}) of copies of a part!".
                format(num_copies))
            raise Exception
        if num_copies < 0:
            logger.error(
                "Can't make a negative number ({}) of copies of a part!".
                format(num_copies))
            raise Exception

        # Now make copies of the part one-by-one.
        copies = []
        for i in range(num_copies):

            # Make a shallow copy of the part.
            cpy = copy(self)

            # The shallow copy will just put references to the pins of the
            # original into the copy, so create independent copies of the pins.
            cpy.pins = []
            for p in getattr(self, 'pins', None):
                cpy.pins.append(p.copy())

            # Make sure all the pins have a reference to this new part copy.
            cpy.associate_pins()

            # Clear the part reference of the copied part so a unique reference
            # can be assigned when the part is added to the circuit.
            # (This is not strictly necessary since the part reference will be
            # adjusted to be unique if needed during the addition process.)
            cpy._ref = None

            # Copied part starts off not being in any circuit.
            cpy.circuit = None

            # If copy is destined for a netlist, then add it to the Circuit its
            # source came from or else add it to the default Circuit object.
            if dest == NETLIST:
                # Place the copied part in the explicitly-stated circuit,
                # or else into the same circuit as the source part,
                # or else into the default circuit.
                if circuit:
                    circuit += cpy
                elif isinstance(self.circuit, Circuit):
                    self.circuit += cpy
                else:
                    builtins.default_circuit += cpy

            # Enter any new attributes.
            for k, v in attribs.items():
                if isinstance(v, (list, tuple)):
                    try:
                        v = v[i]
                    except IndexError:
                        logger.error(
                            "{} copies of part {} were requested, but too few elements in attribute {}!".
                            format(num_copies, self.name, k))
                        raise Exception
                setattr(cpy, k, v)

            # Add the part copy to the list of copies.
            copies.append(cpy)

        return list_or_scalar(copies)

    # Make copies with the multiplication operator or by calling the object.
    __mul__ = copy
    __rmul__ = copy
    __call__ = copy

    def add_pins(self, *pins):
        """Add one or more pins to a part."""
        for pin in flatten(pins):
            pin.part = self
            self.pins.append(pin)
        return self

    __iadd__ = add_pins

    def get_pins(self, *pin_ids, **criteria):
        """
        Return list of part pins selected by pin numbers or names.

        Args:
            pin_ids: A list of strings containing pin names, numbers,
                regular expressions, slices, lists or tuples. If empty,
                then it will select all pins.

        Keyword Args:
            criteria: Key/value pairs that specify attribute values the
                pins must have in order to be selected.

        Returns:
            A list of pins matching the given IDs and satisfying all the criteria,
            or just a single Pin object if only a single match was found.
            Or None if no match was found.

        Notes:
            Pins can be selected from a part by using brackets like so::

                atmega = Part('atmel', 'ATMEGA16U2')
                net = Net()
                atmega[1] += net  # Connects pin 1 of chip to the net.
                net += atmega['.*RESET.*']  # Connects reset pin to the net.
        """

        from .NetPinList import NetPinList
        from .Alias import Alias

        # If no pin identifiers were given, then use a wildcard that will
        # select all pins.
        if not pin_ids:
            pin_ids = ['.*']

        # Determine the minimum and maximum pin ids if they don't already exist.
        if 'min_pin' not in dir(self) or 'max_pin' not in dir(self):
            self.min_pin, self.max_pin = self._find_min_max_pins()

        # Go through the list of pin IDs one-by-one.
        pins = NetPinList()
        for p_id in expand_indices(self.min_pin, self.max_pin, *pin_ids):

            # Does pin ID (either integer or string) match a pin number...
            tmp_pins = filter_list(self.pins, num=re.escape(str(p_id)), **criteria)
            if tmp_pins:
                pins.extend(tmp_pins)
                continue

            # OK, assume it's not a pin number but a pin name. Look for an
            # exact match.
            name = '^' + re.escape(p_id) + '$'
            tmp_pins = filter_list(self.pins, name=name, **criteria)
            if tmp_pins:
                pins.extend(tmp_pins)
                continue

            # OK, now check pin aliases for an exact match.
            tmp_pins = filter_list(self.pins, alias=name, **criteria)
            if tmp_pins:
                pins.extend(tmp_pins)
                continue

            # OK, pin ID is not a pin number and doesn't exactly match a pin
            # name. Does it match a substring within a pin name or alias?
            loose_p_id = ''.join(['.*', p_id, '.*'])
            pins.extend(filter_list(self.pins, name=loose_p_id, **criteria))
            loose_pin_alias = Alias(loose_p_id, id(self))
            pins.extend(
                filter_list(self.pins, alias=loose_pin_alias, **criteria))

        return list_or_scalar(pins)

    # Get pins from a part using brackets, e.g. [1,5:9,'A[0-9]+'].
    __getitem__ = get_pins

    def __setitem__(self, ids, *pins_nets_buses):
        """
        You can't assign to the pins of parts. You must use the += operator.

        This method is a work-around that allows the use of the += for making
        connections to pins while prohibiting direct assignment. Python
        processes something like my_part['GND'] += gnd as follows::

            1. Part.__getitem__ is called with 'GND' as the index. This
               returns a single Pin or a NetPinList.
            2. The Pin.__iadd__ or NetPinList.__iadd__ method is passed
               the thing to connect to the pin (gnd in this case). This method
               makes the actual connection to the part pin or pins. Then it
               creates an iadd_flag attribute in the object it returns.
            3. Finally, Part.__setitem__ is called. If the iadd_flag attribute
               is true in the passed argument, then __setitem__ was entered
               as part of processing the += operator. If there is no
               iadd_flag attribute, then __setitem__ was entered as a result
               of using a direct assignment, which is not allowed.
        """

        # If the iadd_flag is set, then it's OK that we got
        # here and don't issue an error. Also, delete the flag.
        if getattr(pins_nets_buses[0], 'iadd_flag', False):
            del pins_nets_buses[0].iadd_flag
            return

        # No iadd_flag or it wasn't set. This means a direct assignment
        # was made to the pin, which is not allowed.
        logger.error("Can't assign to a part! Use the += operator.")
        raise Exception

    def is_connected(self):
        """
        Return T/F depending upon whether a part is connected in a netlist.

        If a part has pins but none of them are connected to nets, then
        this method will return False. Otherwise, it will return True even if
        the part has no pins (which can be the case for mechanical parts,
        silkscreen logos, or other non-electrical schematic elements).
        """

        # Assume parts without pins (like mech. holes) are always connected.
        if len(self.pins) == 0:
            return True

        # If any pin is found to be connected to a net, return True.
        for p in self.pins:
            if p.is_connected():
                return True

        # No net connections found, so return False.
        return False

    def is_movable(self):
        """
        Return T/F if the part can be moved from one circuit into another.

        This method returns true if:
            1) the part is not in a circuit, or
            2) the part has pins but none of them are connected to nets, or
            3) the part has no pins (which can be the case for mechanical parts,
               silkscreen logos, or other non-electrical schematic elements).
        """

        from .Circuit import Circuit

        return not isinstance(
            self.circuit,
            Circuit) or not self.is_connected() or not self.pins

    def set_pin_alias(self, alias, *pin_ids, **criteria):
        from .Alias import Alias

        pins = to_list(self.get_pins(*pin_ids, **criteria))
        if not pins:
            logger.error("Trying to alias a non-existent pin.")
        if len(pins) > 1:
            logger.error("Trying to give more than one pin the same alias.")
            raise Exception
        for pin in pins:
            pin.alias = Alias(alias, id(self))

    def make_unit(self, label, *pin_ids, **criteria):
        """
        Create a PartUnit from a set of pins in a Part object.

        Parts can be organized into smaller pieces called PartUnits. A PartUnit
        acts like a Part but contains only a subset of the pins of the Part.

        Args:
            label: The label used to identify the PartUnit.
            pin_ids: A list of strings containing pin names, numbers,
                regular expressions, slices, lists or tuples.

        Keyword Args:
            criteria: Key/value pairs that specify attribute values the
                pin must have in order to be selected.

        Returns:
            The PartUnit.
        """

        collisions = self.get_pins(label)
        if collisions:
            logger.warning(
                "Using a label ({}) for a unit of {} that matches one or more of it's pin names ({})!".
                format(label, self.erc_desc(), collisions))
        self.unit[label] = PartUnit(self, *pin_ids, **criteria)
        return self.unit[label]

    def _get_fields(self):
        """
        Return a list of component field names.
        """

        # Get all the component attributes and subtract all the ones that
        # should not appear under "fields" in the netlist or XML.
        fields = set(self.__dict__.keys())
        non_fields = set([
            'name', 'min_pin', 'max_pin', 'hierarchy', '_value', '_ref',
            'ref_prefix', 'unit', 'num_units', 'part_defn', 'definition',
            'fields', 'draw', 'lib', 'fplist', 'do_erc', 'aliases', 'tool',
            'pins', 'footprint', 'circuit'
        ])
        return list(fields - non_fields)

    def generate_netlist_component(self, tool=None):
        """
        Generate the part information for inclusion in a netlist.

        Args:
            tool: The format for the netlist file (e.g., KICAD).
        """

        import skidl

        if tool is None:
            tool = skidl.get_default_tool()

        try:
            gen_func = getattr(self, '_gen_netlist_comp_{}'.format(tool))
            return gen_func()
        except AttributeError:
            logger.error(
                "Can't generate netlist in an unknown ECAD tool format ({}).".
                format(tool))
            raise Exception

    def generate_xml_component(self, tool=None):
        """
        Generate the part information for inclusion in an XML file.

        Args:
            tool: The format for the XML file (e.g., KICAD).
        """

        import skidl

        if tool is None:
            tool = skidl.get_default_tool()

        try:
            gen_func = getattr(self, '_gen_xml_comp_{}'.format(tool))
            return gen_func()
        except AttributeError:
            logger.error(
                "Can't generate XML in an unknown ECAD tool format ({}).".
                format(tool))
            raise Exception

    def erc(self):
        """
        Do electrical rules check on a part in the schematic.
        """

        from .Pin import Pin

        # Don't check this part if the flag is not true.
        if not self.do_erc:
            return

        # Check each pin of the part.
        for p in self.pins:

            # Skip this pin if the flag is false.
            if not p.do_erc:
                continue

            # Error if a pin is unconnected but not of type NOCONNECT.
            if p.net is None:
                if p.func != Pin.NOCONNECT:
                    erc_logger.warning(
                        'Unconnected pin: {p}.'.format(p=p.erc_desc()))

            # Error if a no-connect pin is connected to a net.
            elif p.net.drive != Pin.NOCONNECT_DRIVE:
                if p.func == Pin.NOCONNECT:
                    erc_logger.warning(
                        'Incorrectly connected pin: {p} should not be connected to a net ({n}).'.
                        format(p=p.erc_desc(), n=p.net.name))

    def erc_desc(self):
        """Create description of part for ERC and other error reporting."""
        return "{p.name}/{p.ref}".format(p=self)

    def __str__(self):
        """Return a description of the pins on this part as a string."""
        return '\n {name} ({aliases}): {desc}\n    {pins}'.format(
            name=self.name, 
            aliases=', '.join(getattr(self, 'aliases','')), 
            desc=self.description, 
            pins='\n    '.join([p.__str__() for p in self.pins])
            )

    __repr__ = __str__

    def export(self):
        """Return a string to recreate a Part object."""
        keys = self._get_fields()
        keys.extend(('ref_prefix', 'num_units', 'fplist', 'do_erc', 'aliases',
                     'pin', 'footprint'))
        attribs = []
        attribs.append('{}={}'.format('name', repr(self.name)))
        attribs.append('dest=TEMPLATE')
        attribs.append('tool=SKIDL')
        for k in keys:
            v = getattr(self, k, None)
            if v:
                attribs.append('{}={}'.format(k, repr(v)))
        if self.pins:
            pin_strs = [p.export() for p in self.pins]
            attribs.append('pins=[{}]'.format(','.join(pin_strs)))

        # Return the string after removing all the non-ascii stuff (like ohm symbols).
        return 'Part({})'.format(','.join(attribs)).encode('ascii', 'ignore').decode('utf-8')

    @property
    def ref(self):
        """
        Get, set and delete the part reference.

        When setting the part reference, if another part with the same
        reference is found, the reference for this part is adjusted to make
        it unique.
        """
        return self._ref

    @ref.setter
    def ref(self, r):
        # Remove the existing reference so it doesn't cause a collision if the
        # object is renamed with its existing name.
        self._ref = None

        # Now name the object with the given reference or some variation
        # of it that doesn't collide with anything else in the list.
        self._ref = get_unique_name(self.circuit.parts, 'ref', self.ref_prefix,
                                    r)
        return

    @ref.deleter
    def ref(self):
        """Delete the part reference."""
        self._ref = None

    @property
    def value(self):
        """Get, set and delete the part value."""
        try:
            if isinstance(self._value, UnitValue):
                return self._value
            else:
                return str(self._value)
        except AttributeError:
            # If part has no value, return its part name as the value. This is
            # done in KiCad where a resistor value is set to 'R' if no
            # explicit value was set.
            return self.name

    @value.setter
    def value(self, value):
        """Set the part value."""
        self._value = value

    @value.deleter
    def value(self):
        """Delete the part value."""
        del self._value

    @property
    def foot(self):
        """Get, set and delete the part footprint."""
        return self._foot

    @foot.setter
    def foot(self, footprint):
        """Set the part footprint."""
        self._foot = str(footprint)

    @foot.deleter
    def foot(self):
        """Delete the part footprint."""
        del self._foot


##############################################################################


class SkidlPart(Part):
    """
    A class for storing a SKiDL definition of a schematic part. It's identical
    to its Part superclass except:
        *) The tool defaults to SKIDL.
        *) The destination defaults to TEMPLATE so that it's easier to start
           a part and then add pins to it without it being added to the netlist.
    """

    from .defines import SKIDL, TEMPLATE

    def __init__(self,
                 lib=None,
                 name=None,
                 dest=TEMPLATE,
                 tool=SKIDL,
                 connections=None,
                 **attribs):
        super(SkidlPart, self).__init__(lib, name, dest, tool, connections,
                                        attribs)


##############################################################################


class PartUnit(Part):
    """
    Create a PartUnit from a set of pins in a Part object.

    Parts can be organized into smaller pieces called PartUnits. A PartUnit
    acts like a Part but contains only a subset of the pins of the Part.

    Args:
        part: This is the parent Part whose pins the PartUnit is built from.
        pin_ids: A list of strings containing pin names, numbers,
            regular expressions, slices, lists or tuples.

    Keyword Args:
        criteria: Key/value pairs that specify attribute values the
            pin must have in order to be selected.

    Examples:
        This will return unit 1 from a part::

            lm358 = Part('linear','lm358')
            lm358a = PartUnit(lm358, unit=1)

        Or you can specify the pins directly::

            lm358a = PartUnit(lm358, 1, 2, 3)
    """

    def __init__(self, part, *pin_ids, **criteria):
        # Remember the part that this unit belongs to.
        self.parent = part

        # Give the PartUnit the same information as the Part it is generated
        # from so it can act the same way, just with fewer pins.
        for k, v in part.__dict__.items():
            self.__dict__[k] = v

        # Remove the pins copied from the parent and replace them with
        # pins selected from the parent.
        self.pins = []
        self._add_pins(*pin_ids, **criteria)

    def _add_pins(self, *pin_ids, **criteria):
        """
        Add selected pins from the parent to the part unit.
        """
        try:
            unique_pins = set(self.pins)
        except (AttributeError, TypeError):
            unique_pins = set()
        unique_pins |= set(to_list(self.parent.get_pins(*pin_ids, **criteria)))
        self.pins = list(unique_pins)



from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

philips = SchLib(tool=SKIDL).add_parts(*[
        Part(name='HTRC11001T',dest=TEMPLATE,tool=SKIDL,keywords='HITAG RFID',description='HITAG RF Reader Device, SOIC-14',ref_prefix='U',num_units=1,fplist=['SOIC-14*', 'SO-14*'],do_erc=True,pins=[
            Pin(num='1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='TX2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='TX1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='MODE',do_erc=True),
            Pin(num='6',name='XTAL1',do_erc=True),
            Pin(num='7',name='XTAL2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='SCLK',do_erc=True),
            Pin(num='9',name='DIN',do_erc=True),
            Pin(num='10',name='DOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='CEXT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='QGND',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='RX',do_erc=True)]),
        Part(name='P82B96',dest=TEMPLATE,tool=SKIDL,keywords='I2C Bus Buffer',description='Dual I2C Bus Buffer, DIP8/SO8/TSSOP8',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*', 'SOIC*', 'SO*', 'TSSOP*'],do_erc=True,pins=[
            Pin(num='1',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='RXD-SDA',do_erc=True),
            Pin(num='3',name='TXD-SDA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='TXD-SCL',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='RXD-SCL',do_erc=True),
            Pin(num='7',name='SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='PCA82C251',dest=TEMPLATE,tool=SKIDL,keywords='BUS CAN',description='CAN Transceiver for 24V Systems, SOIC-8',ref_prefix='U',num_units=1,fplist=['SO*', 'SOIC*'],do_erc=True,pins=[
            Pin(num='1',name='TxD',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='RxD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='Vref',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='CAN-',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='CAN+',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='Rsl',do_erc=True)]),
        Part(name='PCA9516',dest=TEMPLATE,tool=SKIDL,keywords='I2C Hub',description='5 channels I2C Hub, SO/TSSOP16',ref_prefix='U',num_units=1,fplist=['SO*', 'SOIC*', 'TSSOP*'],do_erc=True,pins=[
            Pin(num='1',name='SCL0',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='SDA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='SCL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='SDA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='EN1',do_erc=True),
            Pin(num='6',name='SCL2',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='SDA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='EN2',do_erc=True),
            Pin(num='10',name='SCL3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='SDA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='EN3',do_erc=True),
            Pin(num='13',name='SCL4',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='SDA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='EN4',do_erc=True),
            Pin(num='16',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='PCF8563',dest=TEMPLATE,tool=SKIDL,keywords='I2C RTC Clock Calendar',description='Realtime Clock/Calendar I2C Interface, DIP/SOIC/TSSOP-8',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*', 'SOIC*', 'SO*', 'TSSOP*'],do_erc=True,pins=[
            Pin(num='1',name='OSCI',do_erc=True),
            Pin(num='2',name='OSCO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~INT~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='SCL',do_erc=True),
            Pin(num='7',name='CLKO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='PCF8574',dest=TEMPLATE,tool=SKIDL,keywords='I2C Expander',description='8 Bit Port/Expander to I2C Bus, DIP/SOIC-16',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*', 'SO*', 'SOIC*'],do_erc=True,aliases=['PCF8574A'],pins=[
            Pin(num='1',name='A0',do_erc=True),
            Pin(num='2',name='A1',do_erc=True),
            Pin(num='3',name='A2',do_erc=True),
            Pin(num='4',name='P0',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='P1',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='P2',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='P3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='P4',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='P5',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='P6',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='P7',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='~INT~',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='14',name='SCL',do_erc=True),
            Pin(num='15',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='PCF8584',dest=TEMPLATE,tool=SKIDL,keywords='I2C Bus',description='I2C Bus Controller, DIP/SOIC-20',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*', 'SO*', 'SOIC*'],do_erc=True,pins=[
            Pin(num='1',name='CLK',do_erc=True),
            Pin(num='2',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='~IACK~',do_erc=True),
            Pin(num='5',name='~INT~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='A0',do_erc=True),
            Pin(num='7',name='D0',func=Pin.TRISTATE,do_erc=True),
            Pin(num='8',name='D1',func=Pin.TRISTATE,do_erc=True),
            Pin(num='9',name='D2',func=Pin.TRISTATE,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='D3',func=Pin.TRISTATE,do_erc=True),
            Pin(num='12',name='D4',func=Pin.TRISTATE,do_erc=True),
            Pin(num='13',name='D5',func=Pin.TRISTATE,do_erc=True),
            Pin(num='14',name='D6',func=Pin.TRISTATE,do_erc=True),
            Pin(num='15',name='D7',func=Pin.TRISTATE,do_erc=True),
            Pin(num='16',name='~RD~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='17',name='~CS~',do_erc=True),
            Pin(num='18',name='~WR~',do_erc=True),
            Pin(num='19',name='~RST~',func=Pin.BIDIR,do_erc=True)]),
        Part(name='PCF8591',dest=TEMPLATE,tool=SKIDL,keywords='I2C ADC DAC',description='4ch ADC, 1 DAC, I2C Bus Interface, DIP/SOIC-16',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*', 'SO*', 'SOIC*'],do_erc=True,pins=[
            Pin(num='1',name='AIN0',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='AIN1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='AIN2',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='AIN3',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='A0',do_erc=True),
            Pin(num='6',name='A1',do_erc=True),
            Pin(num='7',name='A2',do_erc=True),
            Pin(num='8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='SCL',do_erc=True),
            Pin(num='11',name='OSC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='EXT',do_erc=True),
            Pin(num='13',name='AGND',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='VREF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='15',name='AOUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='SAA7182',dest=TEMPLATE,tool=SKIDL,keywords='Video Encoder',description='Digital Video Encoder, Obsolete',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='~RESN~',do_erc=True),
            Pin(num='3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='SA',do_erc=True),
            Pin(num='5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='OVL2',do_erc=True),
            Pin(num='7',name='OVL1',do_erc=True),
            Pin(num='8',name='OVL0',do_erc=True),
            Pin(num='9',name='KEY',do_erc=True),
            Pin(num='10',name='DP0',do_erc=True),
            Pin(num='20',name='TTXRQ',func=Pin.OUTPUT,do_erc=True),
            Pin(num='30',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='CDIR',do_erc=True),
            Pin(num='60',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='70',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='80',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='DP1',do_erc=True),
            Pin(num='21',name='TTX',do_erc=True),
            Pin(num='31',name='MP3',do_erc=True),
            Pin(num='41',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='R',func=Pin.OUTPUT,do_erc=True),
            Pin(num='71',name='Y',func=Pin.OUTPUT,do_erc=True),
            Pin(num='81',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='DP2',do_erc=True),
            Pin(num='22',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='MP2',do_erc=True),
            Pin(num='42',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VREFL',func=Pin.PASSIVE,do_erc=True),
            Pin(num='72',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='DP3',do_erc=True),
            Pin(num='33',name='MP1',do_erc=True),
            Pin(num='53',name='VREFH',func=Pin.PASSIVE,do_erc=True),
            Pin(num='63',name='CUR',do_erc=True),
            Pin(num='73',name='CVBS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='83',name='SCL',do_erc=True),
            Pin(num='14',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='34',name='MP0',do_erc=True),
            Pin(num='44',name='XTALI',do_erc=True),
            Pin(num='54',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='MP7',do_erc=True),
            Pin(num='35',name='RCV1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='XTAL',func=Pin.OUTPUT,do_erc=True),
            Pin(num='55',name='B',func=Pin.OUTPUT,do_erc=True),
            Pin(num='75',name='VREFH',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='DP4',do_erc=True),
            Pin(num='26',name='MP6',do_erc=True),
            Pin(num='36',name='RCV2',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='VREFL',func=Pin.PASSIVE,do_erc=True),
            Pin(num='17',name='DP5',do_erc=True),
            Pin(num='27',name='MP5',do_erc=True),
            Pin(num='47',name='CREF',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='67',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='77',name='AP',do_erc=True),
            Pin(num='18',name='DP6',do_erc=True),
            Pin(num='28',name='MP4',do_erc=True),
            Pin(num='38',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='LCC',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='G',func=Pin.OUTPUT,do_erc=True),
            Pin(num='68',name='CUR',do_erc=True),
            Pin(num='78',name='SP',do_erc=True),
            Pin(num='19',name='DP7',do_erc=True),
            Pin(num='29',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='69',name='C',func=Pin.OUTPUT,do_erc=True),
            Pin(num='79',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TDA8501',dest=TEMPLATE,tool=SKIDL,keywords='Video Encoder',description='PAL/NTSC Encoder, RGB or Y/Y-R/Y-B Inputs, DIP/SOIC-20',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*', 'SOIC*'],do_erc=True,pins=[
            Pin(num='1',name='-R.Y',do_erc=True),
            Pin(num='2',name='MCTR',do_erc=True),
            Pin(num='3',name='-B.Y',do_erc=True),
            Pin(num='4',name='H/2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='Y',do_erc=True),
            Pin(num='6',name='UOFF',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='R',do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='G',do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='Y+SIN',do_erc=True),
            Pin(num='11',name='B',do_erc=True),
            Pin(num='21',name='B/ADJ',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='VOFF',func=Pin.OUTPUT,do_erc=True),
            Pin(num='22',name='Y+SOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='VREF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='23',name='OSC',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='C/OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='24',name='CS',do_erc=True),
            Pin(num='15',name='FLT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='CVBS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='NTSC/PAL',do_erc=True),
            Pin(num='18',name='NOTCH',do_erc=True),
            Pin(num='19',name='Y/OUT',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='TDA8772',dest=TEMPLATE,tool=SKIDL,keywords='Video DAC Colour 8bit',description='Triple 8bit Video DAC, QFP-44',ref_prefix='U',num_units=1,fplist=['QFP*'],do_erc=True,pins=[
            Pin(num='1',name='R7',do_erc=True),
            Pin(num='2',name='R6',do_erc=True),
            Pin(num='3',name='R5',do_erc=True),
            Pin(num='4',name='R4',do_erc=True),
            Pin(num='5',name='R3',do_erc=True),
            Pin(num='6',name='R2',do_erc=True),
            Pin(num='7',name='R1',do_erc=True),
            Pin(num='8',name='R0',do_erc=True),
            Pin(num='9',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='G0',do_erc=True),
            Pin(num='30',name='B1',do_erc=True),
            Pin(num='40',name='GRE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='SYNC',do_erc=True),
            Pin(num='21',name='CLKR',do_erc=True),
            Pin(num='31',name='B0',do_erc=True),
            Pin(num='41',name='IRFB',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='BLANK',do_erc=True),
            Pin(num='22',name='CLKG',do_erc=True),
            Pin(num='32',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='42',name='GNDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='G7',do_erc=True),
            Pin(num='23',name='CLKB',do_erc=True),
            Pin(num='33',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='43',name='VCCA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='G6',do_erc=True),
            Pin(num='24',name='B7',do_erc=True),
            Pin(num='34',name='VRD',do_erc=True),
            Pin(num='44',name='RED',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='G5',do_erc=True),
            Pin(num='25',name='B6',do_erc=True),
            Pin(num='35',name='VCCA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='G4',do_erc=True),
            Pin(num='26',name='B5',do_erc=True),
            Pin(num='36',name='BLU',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='G3',do_erc=True),
            Pin(num='27',name='B4',do_erc=True),
            Pin(num='37',name='GNDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='G2',do_erc=True),
            Pin(num='28',name='B3',do_erc=True),
            Pin(num='38',name='IRFA',func=Pin.PASSIVE,do_erc=True),
            Pin(num='19',name='G1',do_erc=True),
            Pin(num='29',name='B2',do_erc=True),
            Pin(num='39',name='VCCA',func=Pin.PWRIN,do_erc=True)])])